@@ -476,21 +476,25 @@ class WitlessRunner(object):
         else:
             event_loop = asyncio.SelectorEventLoop()
         asyncio.set_event_loop(event_loop)
-        # include the subprocess manager in the asyncio event loop
-        results = event_loop.run_until_complete(
-            run_async_cmd(
-                event_loop,
-                cmd,
-                protocol,
-                stdin,
-                protocol_kwargs=kwargs,
-                cwd=cwd,
-                env=env,
+        try:
+            # include the subprocess manager in the asyncio event loop
+            results = event_loop.run_until_complete(
+                run_async_cmd(
+                    event_loop,
+                    cmd,
+                    protocol,
+                    stdin,
+                    protocol_kwargs=kwargs,
+                    cwd=cwd,
+                    env=env,
+                )
             )
-        )
-        # terminate the event loop, cannot be undone, hence we start a fresh
-        # one each time (see BlockingIOError notes above)
-        event_loop.close()
+        finally:
+            # be kind to callers and leave asyncio as we found it
+            asyncio.set_event_loop(None)
+            # terminate the event loop, cannot be undone, hence we start a fresh
+            # one each time (see BlockingIOError notes above)
+            event_loop.close()
 
         # log before any exception is raised
         lgr.log(8, "Finished running %r with status %s", cmd, results['code'])
