@@ -38,6 +38,7 @@ from ..utils import (
     setup_exceptionhook,
 )
 from ..dochelpers import exc_str
+from ..version import __full_version__
 
 
 def _license_info():
@@ -65,8 +66,12 @@ THE SOFTWARE.
 
 
 class ArgumentParserDisableAbbrev(argparse.ArgumentParser):
-    # Don't accept abbreviations for long options. With py3.5 and above, we
-    # could just use allow_abbrev=False.
+    # Don't accept abbreviations for long options. This kludge was originally
+    # added at a time when our minimum required Python version was below 3.5,
+    # preventing us from using allow_abbrev=False. Now our minimum Python
+    # version is high enough, but we still can't use allow_abbrev=False because
+    # it suffers from the problem described in 6b3f2fffe (BF: cmdline: Restore
+    # handling of short options, 2018-07-23).
     #
     # Modified from the solution posted at
     # https://bugs.python.org/issue14910#msg204678
@@ -88,6 +93,8 @@ def setup_parser(
         cmdlineargs,
         formatter_class=argparse.RawDescriptionHelpFormatter,
         return_subparsers=False,
+        # Was this triggered by argparse?
+        completing=False,
         # prevent loading of extension entrypoints when --help is requested
         # this is enabled when building docs to avoid pollution of generated
         # manpages with extensions commands (that should appear in their own
@@ -204,10 +211,10 @@ def setup_parser(
     try:
         parsed_args, unparsed_args = parser._parse_known_args(
             cmdlineargs[1:], argparse.Namespace())
-        if not unparsed_args:
+        if not (completing or unparsed_args):
             fail_handler(parser, msg="too few arguments", exit_code=2)
-        lgr.debug("Command line args 1st pass. Parsed: %s Unparsed: %s",
-                  parsed_args, unparsed_args)
+        lgr.debug("Command line args 1st pass for DataLad %s. Parsed: %s Unparsed: %s",
+                  __full_version__, parsed_args, unparsed_args)
     except Exception as exc:
         lgr.debug("Early parsing failed with %s", exc_str(exc))
         need_single_subparser = False
@@ -224,7 +231,7 @@ def setup_parser(
         need_single_subparser = False
         if not help_ignore_extensions:
             add_entrypoints_to_interface_groups(interface_groups)
-    elif unparsed_arg.startswith('-'):  # unknown option
+    elif not completing and unparsed_arg.startswith('-'):  # unknown option
         fail_with_short_help(parser,
                              msg="unrecognized argument %s" % unparsed_arg,
                              exit_code=2)
@@ -240,7 +247,10 @@ def setup_parser(
 
         if unparsed_arg not in known_commands:
             # check if might be coming from known extensions
-            from ..interface import _known_extension_commands
+            from ..interface import (
+                _known_extension_commands,
+                _deprecated_commands,
+            )
             extension_commands = {
                 c: e
                 for e, commands in _known_extension_commands.items()
@@ -250,12 +260,17 @@ def setup_parser(
             if unparsed_arg in extension_commands:
                 hint = "Command %s is provided by (not installed) extension %s." \
                       % (unparsed_arg, extension_commands[unparsed_arg])
-            fail_with_short_help(
-                parser,
-                hint=hint,
-                provided=unparsed_arg,
-                known=list(known_commands.keys()) + list(extension_commands.keys())
-            )
+            elif unparsed_arg in _deprecated_commands:
+                hint_cmd = _deprecated_commands[unparsed_arg]
+                hint = "Command %r was deprecated" % unparsed_arg
+                hint += (" in favor of %r command." % hint_cmd) if hint_cmd else '.'
+            if not completing:
+                fail_with_short_help(
+                    parser,
+                    hint=hint,
+                    provided=unparsed_arg,
+                    known=list(known_commands.keys()) + list(extension_commands.keys())
+                )
         if need_single_subparser is None:
             need_single_subparser = unparsed_arg
 
@@ -433,7 +448,7 @@ def main(args=None):
         # Possibly present DataLadRIs were stripped of a leading /
         args = [_fix_datalad_ri(s) for s in args]
     # PYTHON_ARGCOMPLETE_OK
-    parser = setup_parser(args)
+    parser = setup_parser(args, completing="_ARGCOMPLETE" in os.environ)
     try:
         import argcomplete
         argcomplete.autocomplete(parser)
@@ -529,7 +544,9 @@ def main(args=None):
             except CommandError as exc:
                 # behave as if the command ran directly, importantly pass
                 # exit code as is
-                exc_msg = str(exc)
+                # to not duplicate any captured output in the exception
+                # rendering, will come next
+                exc_msg = exc.to_str(include_output=False)
                 if exc_msg:
                     msg = exc_msg.encode() if isinstance(exc_msg, str) else exc_msg
                     os.write(2, msg + b"\n")
