@@ -13,6 +13,7 @@ import os.path as op
 from os import linesep
 
 from distutils.version import LooseVersion
+from itertools import chain
 
 from datalad.dochelpers import exc_str
 from datalad.log import lgr
@@ -133,7 +134,7 @@ class ExternalVersions(object):
 
     UNKNOWN = UnknownVersion()
 
-    CUSTOM = {
+    _CUSTOM = {
         'cmd:annex': _get_annex_version,
         'cmd:git': _get_git_version,
         'cmd:bundled-git': _get_bundled_git_version,
@@ -141,7 +142,8 @@ class ExternalVersions(object):
         'cmd:system-ssh': _get_system_ssh_version,
         'cmd:7z': _get_system_7z_version,
     }
-    INTERESTING = (
+    _INTERESTING = (
+        'annexremote',
         'appdirs',
         'boto',
         'exifread',
@@ -162,6 +164,8 @@ class ExternalVersions(object):
 
     def __init__(self):
         self._versions = {}
+        self.CUSTOM = self._CUSTOM.copy()
+        self.INTERESTING = list(self._INTERESTING)  # make mutable for `add`
 
     @classmethod
     def _deduce_version(klass, value):
@@ -245,13 +249,57 @@ class ExternalVersions(object):
 
         return self._versions.get(modname, self.UNKNOWN)
 
-    def keys(self):
-        """Return names of the known modules"""
+    def keys(self, query=False):
+        """Return names of the known modules
+
+        Parameters
+        ----------
+        query: bool, optional
+          If True, we will first query all CUSTOM and INTERESTING entries
+          to make sure we have them known.
+        """
+        if query:
+            [self[k] for k in chain(self.CUSTOM, self.INTERESTING)]
         return self._versions.keys()
 
     def __contains__(self, item):
         return bool(self[item])
 
+    def add(self, name, func=None):
+        """Add a version checker
+
+        This method allows third-party libraries to define additional checks.
+        It will not add `name` if already exists.  If `name` exists and `func`
+        is different - it will override with a new `func`.  Added entries will
+        be included in the output of `dumps(query=True)`.
+
+        Parameters
+        ----------
+        name: str
+          Name of the check (usually a name of the Python module, or an
+          external command prefixed with "cmd:")
+        func: callable, optional
+          Function to be called to obtain version information. This should be
+          defined when checking the version of something that is not a Python
+          module or when this class's method for determining the version of a
+          Python module isn't sufficient.
+        """
+        if func:
+            func_existing = self.CUSTOM.get(name, None)
+            was_known = False
+            if func_existing and func_existing is not func:
+                lgr.debug(
+                    "Adding a new custom version checker %s for %s, "
+                    "old one: %s", func, name, func_existing)
+                was_known = name in self._versions
+            self.CUSTOM[name] = func
+            if was_known:
+                # pop and query it again right away to possibly replace with a new value
+                self._versions.pop(name)
+                _ = self[name]
+        elif name not in self.INTERESTING:
+            self.INTERESTING.append(name)
+
     @property
     def versions(self):
         """Return dictionary (copy) of versions"""
@@ -271,11 +319,9 @@ class ExternalVersions(object):
           To query for versions of all "registered" custom externals, so to
           get those which weren't queried for yet
         """
-        if query:
-            [self[k] for k in tuple(self.CUSTOM) + self.INTERESTING]
         if indent and (indent is True):
             indent = ' '
-        items = ["%s=%s" % (k, self._versions[k]) for k in sorted(self._versions)]
+        items = ["%s=%s" % (k, self._versions[k]) for k in sorted(self.keys(query=query))]
         out = "%s" % preamble if preamble else ''
         if indent is not None:
             if preamble:
